==> deposits_ui_kit-0.0.1.tar.gz: example/lib/widgetbook/toggle/toggle.dart <==
import 'package:deposits_ui_kit/deposits_ui_kit.dart';
import 'package:flutter/material.dart';
import 'package:widgetbook/widgetbook.dart';

WidgetbookUseCase basicToggle(BuildContext context) {
  return WidgetbookUseCase(
      name: 'Toggle/Basic',
      builder: (context) => Scaffold(
          appBar: DepAppbarWidget(
            titleWidget: const DepText(
              text: "Basic Toggle",
              txtColor: Colors.white,
              font: 18,
            ),
            addBackButton: false,
            addCloseButton: false,
            backgroundColor: primaryColor,
          ),
          body: StatefulBuilder(builder: (context, setState) {
            return Container(
                alignment: Alignment.center,
                padding: const EdgeInsets.symmetric(
                  horizontal: 16,
                ),
                child: DepToggle(
                  onChanged: (val) {},
                  value: true,
                  type: context.knobs.options(
                      label: 'Loader Type',
                      description: 'Select Loader Type',
                      options: const [
                        Option(
                          label: 'IOS',
                          value: DepToggleType.ios,
                        ),
                        Option(
                          label: 'Android',
                          value: DepToggleType.android,
                        ),
                        Option(
                          label: 'Square',
                          value: DepToggleType.square,
                        ),
                      ]),
                ));
          })));
}

==> deposits_ui_kit-0.0.10.tar.gz: example/lib/widgetbook/toggle/toggle.dart <==
import 'package:deposits_ui_kit/deposits_ui_kit.dart';
import 'package:deposits_ui_kit_example/widgetbook/constants/constants.dart';
import 'package:flutter/material.dart';
import 'package:widgetbook/widgetbook.dart';

WidgetbookUseCase basicToggle(BuildContext context) {
  return WidgetbookUseCase(
      name: 'Toggle/Basic',
      builder: (context) => Scaffold(
          appBar: DepAppbarWidget(
            titleWidget: const DepText(
              text: "Basic Toggle",
              txtColor: Colors.white,
              font: 18,
            ),
            addBackButton: false,
            addCloseButton: false,
            backgroundColor: primaryColor,
          ),
          body: StatefulBuilder(builder: (context, setState) {
            return Container(
                alignment: Alignment.center,
                padding: const EdgeInsets.symmetric(
                  horizontal: 16,
                ),
                child: DepToggle(
                  onChanged: (val) {},
                  value: true,
                  disabledTrackColor: gray200,
                  disabledThumbColor: white,
                  enabledThumbColor: white,
                  enabledTrackColor: green600,
                  type: context.knobs.list(
                      label: 'Loader Type',
                      description: 'Select Loader Type',
                      initialOption: DepToggleType.ios,
                      labelBuilder: (value) {
                        return getDepToggleTypeLabel(value);
                      },
                      options: depToggleTypeOptions),
                ));
          })));
}
